@@ -34,3 +34,8 @@ def set_cache(key, value, exp=DEFAULT_EXP_TIME):
 @safe_cache
 def get_cache(key):
     return redis_client.get(key)
+
+# multiple caches
+@safe_cache
+def get_mcache(keys):
+    return redis_client.mget(keys)
